<?php

namespace Cms\Model\AddressBook\Trip;

use NewcomDigital\Enum\Enum;

/**
 * Class TripLinkType
 * @package Cms\Model\AddressBook\Trip
 */
class TripLinkType extends Enum
{
    public const LINE = 'line';

    public const ROAD = 'road';
}
